@@ -1,5 +1,5 @@
 #
-# $Id: Encode.pm,v 3.09 2021/05/14 10:44:18 dankogai Exp dankogai $
+# $Id: Encode.pm,v 3.10 2021/05/18 07:42:45 dankogai Exp dankogai $
 #
 package Encode;
 use strict;
@@ -7,7 +7,7 @@ use warnings;
 use constant DEBUG => !!$ENV{PERL_ENCODE_DEBUG};
 our $VERSION;
 BEGIN {
-    $VERSION = sprintf "%d.%02d", q$Revision: 3.09 $ =~ /(\d+)/g;
+    $VERSION = sprintf "%d.%02d", q$Revision: 3.10 $ =~ /(\d+)/g;
     require XSLoader;
     XSLoader::load( __PACKAGE__, $VERSION );
 }
@@ -489,7 +489,7 @@ followed by C<encode> as follows:
 
 B<WARNING>: L<This function can produce invalid UTF-8!|/UTF-8 vs. utf8 vs. UTF8>
 Do not use it for data exchange.
-Unless you want Perl’s older "lax" mode, prefer
+Unless you want Perl's older "lax" mode, prefer
 C<$octets = encode("UTF-8", $string)>.
 
 Equivalent to C<$octets = encode("utf8", $string)>.  The characters in
@@ -503,7 +503,7 @@ as a sequence of octets.  Because all possible characters in Perl have a
 
 B<WARNING>: L<This function accepts invalid UTF-8!|/UTF-8 vs. utf8 vs. UTF8>
 Do not use it for data exchange.
-Unless you want Perl’s older "lax" mode, prefer
+Unless you want Perl's older "lax" mode, prefer
 C<$string = decode("UTF-8", $octets [, CHECK])>.
 
 Equivalent to C<$string = decode("utf8", $octets [, CHECK])>.
@@ -918,7 +918,7 @@ important distinction between C<"UTF-8"> and C<"utf8">.
   encode("UTF-8", "\x{FFFF_FFFF}", 1); # croaks
 
 This distinction is also important for decoding. In the following,
-C<$s> stores character U+200000, which exceeds UTF-8’s allowed range.
+C<$s> stores character U+200000, which exceeds UTF-8's allowed range.
 C<$s> thus stores an invalid Unicode code point:
 
   $s = decode("utf8", "\xf8\x88\x80\x80\x80");
